// This extension was developed by :
// * Mark Bokil http://markbokil.com
// * http://markbokil.com/downloads/extensions/lookingglass
// version: 1.1
// date: 8-25-12
// License: GPLv2+

const St = imports.gi.St;
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;
const Util = imports.misc.util;
const Main = imports.ui.main;
const Lang = imports.lang;
const GLib = imports.gi.GLib;
const Shell = imports.gi.Shell;
const Gettext = imports.gettext.domain('markbokil.com-extensions');
const _ = Gettext.gettext;
const ExtensionsPath = GLib.build_filenamev([global.userdatadir, 'extensions/']);


function init(metadata) 
{		
	return new LookingGlass(metadata);
}

function LookingGlass(metadata)
{	
	this._init();
}

LookingGlass.prototype =
{
	__proto__: PanelMenu.Button.prototype,
	
    	_init: function(gicon) 
    	{			
		PanelMenu.Button.prototype._init.call(this, St.Align.START);

		this._iconActor = new St.Icon({ icon_name: 'utilities-terminal-symbolic',
                                   		icon_type: St.IconType.SYMBOLIC,
                                        style_class: 'system-status-icon' });

        this.actor.add_actor(this._iconActor); 
		this._iconActor.get_parent().add_style_class_name("panelButtonWidth");
	},

	enable: function()
	{
		Main.panel._rightBox.insert_child_at_index(this.actor, 0);
		Main.panel._menus.addMenu(this.menu);
	},

	disable: function()
	{
		this.menu.removeAll();
		Main.panel._menus.removeMenu(this.menu);
		Main.panel._rightBox.remove_actor(this.actor);
	},

	_onButtonPress: function(actor, event) {
        let button = event.get_button();
        if (button == 1) {
        	this.menu.removeAll();
            this._onLookingGlass(); 
        } else if (button == 3) { 
            this.menu.removeAll();
            this._buildContextMenu(); 
        }
       
    	return PanelMenu.Button.prototype._onButtonPress.call(this, actor, event);
    },
	
	_buildContextMenu: function()
	{    			
		// reload theme
		this.reloadTheme = new PopupMenu.PopupMenuItem("Reload Theme");
		this.menu.addMenuItem(this.reloadTheme);
		this.reloadTheme.connect('activate', Lang.bind(this, this._onReloadTheme));

		this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());

		// open extensions folder
		this.ef = new PopupMenu.PopupMenuItem("Open Extensions Folder");
		this.menu.addMenuItem(this.ef);
		this.ef.connect('activate', Lang.bind(this, this._doLocalFolder));

		// restart
		this.restart = new PopupMenu.PopupMenuItem("Restart Shell");
		this.menu.addMenuItem(this.restart);
		this.restart.connect('activate', Lang.bind(this, this._onRestart));
	},

	_onLookingGlass: function() {
		Main.createLookingGlass().toggle();
	},

	_doLocalFolder: function() {
		Main.Util.trySpawnCommandLine('xdg-open ' + ExtensionsPath);
	},

	_doLocalExtensions: function() {
		Main.Util.trySpawnCommandLine('xdg-open https://extensions.gnome.org/local/');
	},

	_onReloadTheme: function() {
		Main.loadTheme();
	},

	_onRestart: function() {
		global.reexec_self();
	}
}
